tsseg.algorithms.hmm package
============================

Simple univariate HMM with Gaussian emissions, Baum-Welch + Viterbi.

| **Type:** state detection
| **Supervision:** semi-supervised
| **Scope:** univariate only, pure Python

**Implementation:** Adapted from aeon. BSD 3-Clause.

**Reference:** Rabiner (1989), Proc. IEEE.

Submodules
----------

tsseg.algorithms.hmm.detector module
------------------------------------

.. automodule:: tsseg.algorithms.hmm.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.hmm
   :members:
   :show-inheritance:
   :undoc-members:
